anderson_darling_py

Function anderson_darling_py 

pub fn anderson_darling_py(
    py: Python<'_>,
    x: &Bound<'_, PyArray1<f64>>,
) -> PyResult<Py<PyAny>>
Anderson-Darling test for normality.

Tests whether a sample comes from a normal distribution using the Anderson-Darling statistic. More sensitive to deviations in the tails than the Shapiro-Wilk test.

Parameters: x: Array of sample data

Returns: Dictionary with ‘statistic’ and ‘pvalue’ keys